@@ -611,11 +611,312 @@ class VeCodePipeline:
             name_filter=name_filter,
             pipeline_ids=pipeline_ids,
         )
-    
-def formatted_timestamp():
-    """生成格式化的时间戳字符串"""
-    from datetime import datetime
-    return datetime.now().strftime("%Y%m%d%H%M%S")
+    def list_pipeline_run_stages_inner(
+        self,
+        workspace_id: str,
+        pipeline_id: str,
+        pipeline_run_id: str,
+    ) -> dict:
+        """
+        List all stages of a pipeline run with detailed task and step information.
+        
+        Args:
+            workspace_id: The workspace ID
+            pipeline_id: The pipeline ID
+            pipeline_run_id: The pipeline run ID to query stages from
+            
+        Returns:
+            The response containing stage items and context:
+            {
+                "Items": [
+                    {
+                        "Id": "...",
+                        "Name": "...",
+                        "DisplayName": "...",
+                        "Status": "...",
+                        "Tasks": [...]
+                    }
+                ],
+                "context": {...}
+            }
+            
+        Raises:
+            Exception: If the request fails
+            
+        Example:
+            # List pipeline run stages
+            result = cp.list_pipeline_run_stages_inner(
+                workspace_id="x",
+                pipeline_id="x",
+                pipeline_run_id="x"
+            )
+            
+            # Access stage information
+            for stage in result["Items"]:
+                print(f"Stage: {stage['DisplayName']} - Status: {stage['Status']}")
+                for task in stage["Tasks"]:
+                    print(f"  Task: {task['DisplayName']} - Status: {task['Status']}")
+        """
+        logger.info(f"Listing pipeline run stages for run {pipeline_run_id}...")
+        
+        request_body = {
+            "WorkspaceId": workspace_id,
+            "PipelineId": pipeline_id,
+            "PipelineRunId": pipeline_run_id,
+        }
+        
+        res = ve_request(
+            request_body=request_body,
+            action="ListPipelineRunStagesInner",
+            ak=self.volcengine_access_key,
+            sk=self.volcengine_secret_key,
+            service=self.service,
+            version=self.version,
+            region=self.region,
+            host=self.host,
+            content_type=self.content_type,
+        )
+        
+        try:
+            result = res["Result"]
+            items_count = len(result.get("Items", []))
+            logger.info(f"Successfully listed pipeline run stages, found {items_count} stages")
+            return result
+        except KeyError:
+            raise Exception(f"List pipeline run stages failed: {res}")
+
+    def get_task_run_log_download_uri(
+        self,
+        workspace_id: str,
+        pipeline_id: str,
+        pipeline_run_id: str,
+        task_run_id: str,
+        task_id: str,
+        step_name: str,
+    ) -> str:
+        """
+        Get the download URI for task run logs.
+        
+        Args:
+            workspace_id: The workspace ID
+            pipeline_id: The pipeline ID
+            pipeline_run_id: The pipeline run ID
+            task_run_id: The task run ID
+            task_id: The task ID
+            step_name: The step name to get logs from
+            
+        Returns:
+            The download URL for the task run logs
+            
+        Raises:
+            Exception: If the request fails
+            
+        Example:
+            # Get task run log download URI
+            log_url = cp.get_task_run_log_download_uri(
+                workspace_id="****",
+                pipeline_id="****",
+                pipeline_run_id="****",
+                task_run_id="****",
+                task_id="****",
+                step_name="step-name"
+            )
+            print(f"Log URL: {log_url}")
+        """
+        logger.info(f"Getting task run log download URI for task run {task_run_id}, step {step_name}...")
+        
+        request_body = {
+            "WorkspaceId": workspace_id,
+            "PipelineId": pipeline_id,
+            "PipelineRunId": pipeline_run_id,
+            "TaskRunId": task_run_id,
+            "TaskId": task_id,
+            "StepName": step_name,
+        }
+        
+        res = ve_request(
+            request_body=request_body,
+            action="GetTaskRunLogDownloadURI",
+            ak=self.volcengine_access_key,
+            sk=self.volcengine_secret_key,
+            service=self.service,
+            version=self.version,
+            region=self.region,
+            host=self.host,
+            content_type=self.content_type,
+        )
+        
+        try:
+            url = res["Result"]["Url"]
+            logger.info(f"Successfully retrieved task run log download URI")
+            return url
+        except KeyError:
+            raise Exception(f"Get task run log download URI failed: {res}")
+
+    def download_and_merge_pipeline_logs(
+        self,
+        workspace_id: str,
+        pipeline_id: str,
+        pipeline_run_id: str,
+        output_file: str = "pipeline_run.log",
+    ) -> str:
+        """
+        Download and merge all step logs from a pipeline run into a single file.
+        
+        This function retrieves all stages, tasks, and steps from a pipeline run,
+        downloads the log for each step, and merges them in chronological order.
+        If a step log fails to download, it records the failure instead of raising an error.
+        
+        Args:
+            workspace_id: The workspace ID
+            pipeline_id: The pipeline ID
+            pipeline_run_id: The pipeline run ID to download logs from
+            output_file: The output file path for merged logs (default: "pipeline_run.log")
+            
+        Returns:
+            The path to the merged log file
+            
+        Raises:
+            Exception: If unable to retrieve pipeline run stages
+            
+        Example:
+            # Download and merge all logs
+            log_file = cp.download_and_merge_pipeline_logs(
+                workspace_id="******",
+                pipeline_id="******",
+                pipeline_run_id="******",
+                output_file="build_logs.log"
+            )
+            
+            # Read and display first 100 lines
+            with open(log_file, 'r', encoding='utf-8') as f:
+                lines = f.readlines()
+                for line in lines[:100]:
+                    print(line.rstrip())
+        """
+        logger.info(f"Downloading and merging logs for pipeline run {pipeline_run_id}...")
+        
+        # Get all stages information
+        try:
+            stages_data = self.list_pipeline_run_stages_inner(
+                workspace_id=workspace_id,
+                pipeline_id=pipeline_id,
+                pipeline_run_id=pipeline_run_id,
+            )
+        except Exception as e:
+            logger.error(f"Failed to retrieve pipeline run stages: {e}")
+            raise
+        
+        # Open output file for writing
+        with open(output_file, 'w', encoding='utf-8') as out_file:
+            # Write header information
+            out_file.write("=" * 80 + "\n")
+            out_file.write("PIPELINE RUN LOG\n")
+            out_file.write("=" * 80 + "\n")
+            out_file.write(f"Workspace ID:     {workspace_id}\n")
+            out_file.write(f"Pipeline ID:      {pipeline_id}\n")
+            out_file.write(f"Pipeline Run ID:  {pipeline_run_id}\n")
+            out_file.write("=" * 80 + "\n\n")
+            
+            # Process each stage
+            stages = stages_data.get("Items", [])
+            total_steps = 0
+            successful_downloads = 0
+            failed_downloads = 0
+            
+            for stage_idx, stage in enumerate(stages, 1):
+                stage_id = stage.get("Id", "unknown")
+                stage_name = stage.get("Name", "unknown")
+                stage_display_name = stage.get("DisplayName", "unknown")
+                stage_status = stage.get("Status", "unknown")
+                
+                out_file.write("\n" + "=" * 80 + "\n")
+                out_file.write(f"STAGE {stage_idx}: {stage_display_name} ({stage_name})\n")
+                out_file.write(f"Stage ID: {stage_id}\n")
+                out_file.write(f"Status: {stage_status}\n")
+                out_file.write("=" * 80 + "\n\n")
+                
+                # Process each task in the stage
+                tasks = stage.get("Tasks", [])
+                for task_idx, task in enumerate(tasks, 1):
+                    task_id = task.get("Id", "unknown")
+                    task_run_id = task.get("TaskRunID", "unknown")
+                    task_name = task.get("Name", "unknown")
+                    task_display_name = task.get("DisplayName", "unknown")
+                    task_status = task.get("Status", "unknown")
+                    task_start_time = task.get("StartTime", "unknown")
+                    task_finish_time = task.get("FinishTime", "unknown")
+                    
+                    out_file.write("\n" + "-" * 80 + "\n")
+                    out_file.write(f"TASK {task_idx}: {task_display_name} ({task_name})\n")
+                    out_file.write(f"Task ID: {task_id}\n")
+                    out_file.write(f"Task Run ID: {task_run_id}\n")
+                    out_file.write(f"Status: {task_status}\n")
+                    out_file.write(f"Start Time: {task_start_time}\n")
+                    out_file.write(f"Finish Time: {task_finish_time}\n")
+                    out_file.write("-" * 80 + "\n\n")
+                    
+                    # Process each step in the task
+                    steps = task.get("Steps", [])
+                    for step_idx, step in enumerate(steps, 1):
+                        step_name = step.get("Name", "unknown")
+                        step_status = step.get("Status", "unknown")
+                        step_start_time = step.get("StartTime", "unknown")
+                        step_finish_time = step.get("FinishTime", "unknown")
+                        
+                        total_steps += 1
+                        
+                        out_file.write(f"\n{'*' * 60}\n")
+                        out_file.write(f"STEP {step_idx}: {step_name}\n")
+                        out_file.write(f"Status: {step_status}\n")
+                        out_file.write(f"Start Time: {step_start_time}\n")
+                        out_file.write(f"Finish Time: {step_finish_time}\n")
+                        out_file.write(f"{'*' * 60}\n\n")
+                        
+                        # Try to download the step log
+                        try:
+                            # Get log download URI
+                            log_url = self.get_task_run_log_download_uri(
+                                workspace_id=workspace_id,
+                                pipeline_id=pipeline_id,
+                                pipeline_run_id=pipeline_run_id,
+                                task_run_id=task_run_id,
+                                task_id=task_id,
+                                step_name=step_name,
+                            )
+                            
+                            # Download the log content
+                            response = requests.get(log_url, timeout=30)
+                            response.raise_for_status()
+                            
+                            log_content = response.text
+                            out_file.write(log_content)
+                            
+                            if not log_content.endswith('\n'):
+                                out_file.write('\n')
+                            
+                            successful_downloads += 1
+                            logger.info(f"Successfully downloaded log for step: {step_name}")
+                            
+                        except Exception as e:
+                            failed_downloads += 1
+                            error_msg = f"[ERROR] Failed to download log for step '{step_name}': {str(e)}\n"
+                            out_file.write(error_msg)
+                            logger.warning(f"Failed to download log for step {step_name}: {e}")
+                        
+                        out_file.write("\n")
+            
+            # Write summary at the end
+            out_file.write("\n" + "=" * 80 + "\n")
+            out_file.write("LOG DOWNLOAD SUMMARY\n")
+            out_file.write("=" * 80 + "\n")
+            out_file.write(f"Total Steps: {total_steps}\n")
+            out_file.write(f"Successful Downloads: {successful_downloads}\n")
+            out_file.write(f"Failed Downloads: {failed_downloads}\n")
+            out_file.write("=" * 80 + "\n")
+        
+        logger.info(f"Log file created: {output_file} ({successful_downloads}/{total_steps} steps downloaded)")
+        return output_file
 
 
 
