@@ -15,6 +15,8 @@
 import json
 
 from agentkit.toolkit.workflows import Workflow
+from agentkit.toolkit.workflows.models import BuildInfo, DeployInfo, StatusInfo, InvokeInfo, WorkflowErrorType
+from agentkit.toolkit.workflows.progress import ProgressLevel
 from typing import Dict, Any, Tuple
 from datetime import datetime
 from agentkit.toolkit.config import (
@@ -25,17 +27,14 @@ from agentkit.toolkit.config import (
 from agentkit.toolkit.integrations.runner import VeAgentkitRuntimeRunner
 from agentkit.utils.misc import generate_runtime_name
 from agentkit.toolkit.integrations.services.cr_service import CRService
-from rich.console import Console
 from agentkit.toolkit.integrations.services.tos_service import TOSService
 
-console = Console()
 
 class VeAgentkitWorkflow(Workflow):
     """VeAgentkit工作流实现 - 使用VeCPCRBuilder进行云上构建"""
     
-    def __init__(self):
-        super().__init__()
-        self.console = Console()
+    def __init__(self, config_manager=None, progress_reporter=None, logger=None):
+        super().__init__(config_manager, progress_reporter, logger)
     
     def prompt_for_config(self, current_config: Dict[str, Any] = None) -> Dict[str, Any]:
         """生成交互式配置"""
@@ -66,18 +65,23 @@ class VeAgentkitWorkflow(Workflow):
             
         return generate_config_from_dataclass(VeAgentkitConfig, current_config)
 
-    def build(self, config: Dict[str, Any]) -> bool:
+    def build(self, config: Dict[str, Any]) -> BuildInfo:
         """构建代理镜像使用VeCPCRBuilder"""
         try:
             from agentkit.toolkit.integrations.builder.ve_core_pipeline_builder import (
                 VeCPCRBuilder, VeCPCRBuilderConfig, VeCPCRBuilderResult
             )
         except ImportError as e:
-            console.print(f"[red]错误: 缺少VeCPCRBuilder依赖 - {e}[/red]")
-            return False
+            self.logger.error(f"Missing VeCPCRBuilder dependency: {e}")
+            self.progress.report(f"依赖错误: {e}", 0, level=ProgressLevel.ERROR)
+            return BuildInfo(
+                success=False,
+                error=f"缺少VeCPCRBuilder依赖: {str(e)}",
+                error_type=WorkflowErrorType.DEPENDENCY_ERROR
+            )
             
         try:
-            console.print("[green]🔨 开始构建Agent镜像...[/green]")
+            self.progress.report("开始构建Agent镜像", 0, level=ProgressLevel.INFO)
             
             # 解析配置
             ve_config = VeAgentkitConfig.from_dict(config)
@@ -91,8 +95,6 @@ class VeAgentkitWorkflow(Workflow):
             # 2. 强制CP名称和runtime名称一致
             ve_config.cp_pipeline_name = ve_config.runtime_name
 
-            
-            
             # 构建VeCPCRBuilder配置
             builder_config = VeCPCRBuilderConfig(
                 common_config=common_config,
@@ -110,6 +112,10 @@ class VeAgentkitWorkflow(Workflow):
                 build_timeout=ve_config.build_timeout
             ).to_dict()
             
+            # 添加Docker构建配置（如果存在）
+            docker_build_config = agent_config.get_docker_build_config()
+            builder_config["docker_build_config"] = docker_build_config.to_dict()
+
             # 执行构建
             builder = VeCPCRBuilder()
             success, build_result = builder.build(builder_config)
@@ -137,7 +143,29 @@ class VeAgentkitWorkflow(Workflow):
                     ve_config.cp_pipeline_name = result.resources.get('pipeline_name')
                 
                 agent_config.update_workflow_config("cloud", ve_config.to_persist_dict())
-                return True
+                
+                self.progress.report("构建完成", 100, level=ProgressLevel.SUCCESS)
+                
+                # Extract tag from image URL
+                image_tag = None
+                if result.image_url and ':' in result.image_url:
+                    image_tag = result.image_url.rsplit(':', 1)[1]
+                
+                return BuildInfo(
+                    success=True,
+                    image_name=result.image_url,
+                    image_id=None,  # VeCPCRBuilder doesn't return image_id
+                    image_tag=image_tag,
+                    build_timestamp=result.build_timestamp,
+                    details={
+                        "pipeline_id": ve_config.cp_pipeline_id,
+                        "cr_instance": ve_config.cr_instance_name,
+                        "cr_namespace": ve_config.cr_namespace_name,
+                        "cr_repo": ve_config.cr_repo_name,
+                        "tos_bucket": ve_config.tos_bucket,
+                        "tos_url": ve_config.tos_object_url
+                    }
+                )
             else:
                 result = VeCPCRBuilderResult.from_dict(build_result)
                 error_msg = result.error_message or "构建失败"
@@ -148,25 +176,43 @@ class VeAgentkitWorkflow(Workflow):
                     ve_config.tos_object_url = result.resources.get('tos_url', ve_config.tos_object_url) 
                     agent_config.update_workflow_config("cloud", ve_config.to_persist_dict())
                 
-                console.print(f"[red]❌ 构建失败: {error_msg}[/red]")
-                return False
+                self.logger.error(f"Build failed: {error_msg}")
+                self.progress.report("构建失败", 0, level=ProgressLevel.ERROR)
+                
+                return BuildInfo(
+                    success=False,
+                    error=error_msg,
+                    error_type=WorkflowErrorType.BUILD_FAILURE,
+                    details={"resources": result.resources} if result.resources else {}
+                )
                 
         except Exception as e:
-            console.print(f"[red]构建错误: {str(e)}[/red]")
-            return False
+            self.logger.error(f"Build error: {e}", exc_info=True)
+            self.progress.report(f"构建错误: {e}", 0, level=ProgressLevel.ERROR)
+            return BuildInfo(
+                success=False,
+                error=str(e),
+                error_type=WorkflowErrorType.UNKNOWN_ERROR,
+                details={"exception": type(e).__name__}
+            )
 
-    def deploy(self, config: Dict[str, Any]) -> bool:
+    def deploy(self, config: Dict[str, Any]) -> DeployInfo:
         """部署代理到云上环境 - 使用VeAgentkitRuntimeRunner"""
         try:
-            console.print("[green]🚀 开始部署Agent...[/green]")
+            self.progress.report("开始部署Agent", 0, level=ProgressLevel.INFO)
             
             # 解析配置
             ve_config = VeAgentkitConfig.from_dict(config)
             
             # 检查镜像URL
-            if not ve_config.cr_image_full_url:
-                console.print("[yellow]⚠️ 未找到镜像URL，请先执行构建[/yellow]")
-                return False
+            if not ve_config.cr_image_full_url or ve_config.cr_image_full_url == "":
+                self.logger.error("No image URL found")
+                self.progress.report("错误: 请先执行build命令构建镜像", 0, level=ProgressLevel.ERROR)
+                return DeployInfo(
+                    success=False,
+                    error="请先执行build命令构建镜像",
+                    error_type=WorkflowErrorType.CONFIG_ERROR
+                )
             
             # 获取公共配置
             agent_config = get_config()
@@ -203,27 +249,54 @@ class VeAgentkitWorkflow(Workflow):
                 ve_config.runtime_role_name = result.get("runtime_role_name", ve_config.runtime_role_name)
                 ve_config.deploy_timestamp = datetime.now().isoformat()
                 agent_config.update_workflow_config("cloud", ve_config.to_persist_dict())
-                console.print(f"[green]✅ 部署完成: {ve_config.cr_image_full_url}[/green]")
-                console.print(f"[green]✅ Runtime ID: {ve_config.runtime_id}[/green]")
-                console.print(f"[green]✅ Runtime Endpoint: {ve_config.runtime_endpoint}[/green]")
-                return True
+                
+                self.progress.report("部署完成", 100, level=ProgressLevel.SUCCESS)
+                
+                return DeployInfo(
+                    success=True,
+                    endpoint_url=ve_config.runtime_endpoint,
+                    service_id=ve_config.runtime_id,
+                    deploy_timestamp=ve_config.deploy_timestamp,
+                    details={
+                        "runtime_name": ve_config.runtime_name,
+                        "image_url": ve_config.cr_image_full_url,
+                        "runtime_apikey_name": ve_config.runtime_apikey_name
+                    }
+                )
             else:
-                console.print(f"[red]❌ 部署失败: {result.get('error', '未知错误')}[/red]")
-                return False
+                error_msg = result.get('error', '未知错误')
+                self.logger.error(f"Deploy failed: {error_msg}")
+                self.progress.report("部署失败", 0, level=ProgressLevel.ERROR)
+                return DeployInfo(
+                    success=False,
+                    error=error_msg,
+                    error_type=WorkflowErrorType.DEPLOY_FAILURE
+                )
             
         except Exception as e:
-            console.print(f"[red]❌ 部署失败: {str(e)}[/red]")
-            return False
+            self.logger.error(f"Deploy error: {e}", exc_info=True)
+            self.progress.report("部署失败", 0, level=ProgressLevel.ERROR)
+            return DeployInfo(
+                success=False,
+                error=str(e),
+                error_type=WorkflowErrorType.UNKNOWN_ERROR,
+                details={"exception": type(e).__name__}
+            )
 
-    def invoke(self, config: Dict[str, Any] = None, args: Dict[str, Any] = None) -> Tuple[bool, Any]:
+    def invoke(self, config: Dict[str, Any] = None, args: Dict[str, Any] = None) -> InvokeInfo:
         """调用云上Runtime - 使用VeAgentkitRuntimeRunner"""
         # 解析配置
         ve_config = VeAgentkitConfig.from_dict(config)
 
         # 检查配置
         if not ve_config.runtime_id:
-            console.print(f"[red]❌ 未配置Runtime ID，请先执行deploy步骤[/red]")
-            return False, {"error": "未配置Runtime ID"}
+            self.logger.error("No runtime ID configured")
+            self.progress.report("未配置Runtime ID", 0, level=ProgressLevel.ERROR)
+            return InvokeInfo(
+                success=False,
+                error="未配置Runtime ID，请先执行deploy步骤",
+                error_type=WorkflowErrorType.CONFIG_ERROR
+            )
         
         try:
             # 创建Runner配置
@@ -244,27 +317,49 @@ class VeAgentkitWorkflow(Workflow):
             success, result = runner.invoke(runner_config, payload, headers)
             
             if success:
-                return True, result
+                # 检测是否是流式响应（生成器）
+                is_streaming = hasattr(result, '__iter__') and not isinstance(result, (dict, str, list, bytes))
+                
+                return InvokeInfo(
+                    success=True,
+                    response=result,
+                    is_streaming=is_streaming
+                )
             else:
-                console.print(f"[red]❌ 云上调用失败: {result}[/red]")
-                return False, {"error": result}
+                self.logger.error(f"Invoke failed: {result}")
+                return InvokeInfo(
+                    success=False,
+                    error=str(result),
+                    error_type=WorkflowErrorType.UNKNOWN_ERROR
+                )
                 
         except Exception as e:
-            console.print(f"[red]❌ 云上调用异常: {str(e)}[/red]")
-            return False, {"error": str(e)}
+            self.logger.error(f"Invoke error: {e}", exc_info=True)
+            return InvokeInfo(
+                success=False,
+                error=str(e),
+                error_type=WorkflowErrorType.UNKNOWN_ERROR,
+                details={"exception": type(e).__name__}
+            )
 
 
-    def status(self, config: VeAgentkitConfig) -> Dict[str, Any]:
+    def status(self, config: Dict[str, Any] = None) -> StatusInfo:
         """获取云上Runtime状态 - 使用VeAgentkitRuntimeRunner"""
+        # 加载配置
+        if config is None:
+            config = get_config().get_workflow_config("cloud")
+        
         # 解析配置
         ve_config = VeAgentkitConfig.from_dict(config)
 
         # 检查配置
         if not ve_config.runtime_id:
-            console.print(f"[yellow]⚠️ 未配置Runtime ID[/yellow]")
-            return {"status": "not_deployed", "message": "未配置Runtime ID"}
-        
-        console.print(f"[green]✅ Runtime ID: {ve_config.runtime_id}[/green]")
+            self.logger.warning("No runtime ID configured")
+            return StatusInfo(
+                success=True,
+                status="not_deployed",
+                details={"message": "未配置Runtime ID"}
+            )
         
         try:
             # 创建Runner配置
@@ -277,19 +372,32 @@ class VeAgentkitWorkflow(Workflow):
             
             # 使用Runner获取状态
             runner = VeAgentkitRuntimeRunner()
-            status_info = runner.status(runner_config)
+            status_data = runner.status(runner_config)
             
-            # 控制台输出
-            if status_info.get("status") == "Ready":
-                console.print(f"[green]✅ Runtime状态为Ready, Endpoint: {status_info.get('endpoint')}[/green]")
+            # Normalize status
+            raw_status = status_data.get("status", "unknown")
+            if raw_status == "Ready":
+                normalized_status = "running"
             else:
-                console.print(f"[yellow]当前Runtime状态: {status_info.get('status')}，状态异常[/yellow]")
+                normalized_status = raw_status.lower()
             
-            return status_info
+            return StatusInfo(
+                success=True,
+                status=normalized_status,
+                endpoint_url=status_data.get("endpoint") or ve_config.runtime_endpoint,
+                service_id=ve_config.runtime_id,
+                details=status_data
+            )
             
         except Exception as e:
-            console.print(f"[red]❌ 获取Runtime状态失败: {str(e)}[/red]")
-            return {"status": "error", "message": str(e)}
+            self.logger.error(f"Status query error: {e}", exc_info=True)
+            return StatusInfo(
+                success=False,
+                status="error",
+                error=str(e),
+                error_type=WorkflowErrorType.UNKNOWN_ERROR,
+                details={"exception": type(e).__name__}
+            )
 
     def stop(self, config: Dict[str, Any] = None) -> bool:
         """停止工作流 - 使用VeAgentkitRuntimeRunner"""
@@ -298,11 +406,12 @@ class VeAgentkitWorkflow(Workflow):
         ve_config = VeAgentkitConfig.from_dict(config)
         
         if not ve_config.runtime_id:
-            console.print("[yellow]⚠️ 未配置Runtime ID，无需停止[/yellow]")
+            self.logger.info("No runtime ID configured, nothing to stop")
+            self.progress.report("未配置Runtime ID，无需停止", 100, level=ProgressLevel.INFO)
             return True
         
         try:
-            console.print("[yellow]🛑 停止VeAgentkit Runtime...[/yellow]")
+            self.progress.report("停止VeAgentkit Runtime", 50, level=ProgressLevel.INFO)
             
             # 创建Runner配置
             runner_config = {
@@ -315,20 +424,31 @@ class VeAgentkitWorkflow(Workflow):
             success = runner.stop(runner_config)
             
             if success:
-                console.print("[green]✅ Runtime停止成功[/green]")
+                self.logger.info("Runtime stopped successfully")
+                self.progress.report("Runtime停止成功", 100, level=ProgressLevel.SUCCESS)
             else:
-                console.print("[red]❌ Runtime停止失败[/red]")
+                self.logger.error("Runtime stop failed")
+                self.progress.report("Runtime停止失败", 0, level=ProgressLevel.ERROR)
             
             return success
             
         except Exception as e:
-            console.print(f"[red]❌ Runtime停止异常: {str(e)}[/red]")
+            self.logger.error(f"Runtime stop error: {e}", exc_info=True)
+            self.progress.report(f"Runtime停止异常: {e}", 0, level=ProgressLevel.ERROR)
             return False
 
-    def destroy(self, config: Dict[str, Any] = None) -> bool:
-        """销毁工作流资源 - 使用VeAgentkitRuntimeRunner"""
+    def destroy(self, config: Dict[str, Any] = None, force: bool = False) -> bool:
+        """销毁工作流资源 - 使用VeAgentkitRuntimeRunner
+        
+        Args:
+            config: 工作流配置（可选）
+            force: 强制销毁，即使遇到错误也继续
+        
+        Returns:
+            bool: 是否成功销毁
+        """
         try:
-            console.print("[red]🗑️ 销毁AgentKit相关资源...[/red]")
+            self.progress.report("销毁AgentKit相关资源", 0, level=ProgressLevel.INFO)
             
             agent_config = get_config()
             if config is None:
@@ -339,6 +459,7 @@ class VeAgentkitWorkflow(Workflow):
             # 销毁Runtime
             if ve_config.runtime_id:
                 try:
+                    self.progress.report("销毁Runtime资源", 50, level=ProgressLevel.INFO)
                     runner_config = {
                         "common_config": {},
                         "runtime_id": ve_config.runtime_id
@@ -346,7 +467,12 @@ class VeAgentkitWorkflow(Workflow):
                     runner = VeAgentkitRuntimeRunner()
                     runner.destroy(runner_config)
                 except Exception as e:
-                    console.print(f"[yellow]⚠️ Runtime销毁失败: {str(e)}[/yellow]")
+                    error_msg = f"Runtime destroy failed: {e}"
+                    self.logger.warning(error_msg)
+                    self.progress.report(f"Runtime销毁失败: {e}", 0, level=ProgressLevel.WARNING)
+                    # 如果不是强制模式，则抛出异常
+                    if not force:
+                        raise
             
             # 重置配置
             ve_config.cr_image_full_url = None
@@ -361,9 +487,11 @@ class VeAgentkitWorkflow(Workflow):
             
             agent_config.update_workflow_config("cloud", ve_config.to_persist_dict())
             
-            console.print("[green]✅ 资源已销毁[/green]")
+            self.logger.info("Resources destroyed successfully")
+            self.progress.report("资源已销毁", 100, level=ProgressLevel.SUCCESS)
             return True
             
         except Exception as e:
-            console.print(f"[red]❌ 销毁失败: {str(e)}[/red]")
+            self.logger.error(f"Destroy error: {e}", exc_info=True)
+            self.progress.report(f"销毁失败: {e}", 0, level=ProgressLevel.ERROR)
             return False
\ No newline at end of file
